![Black Logo](https://raw.githubusercontent.com/ferret-guy/black-with-tabs/master/docs/_static/logo2-readme.png)

# Black with Tabs

**This is not the official Black package! Get that [here](https://github.com/psf/black)!**

Black with tabs is the same black you know and love, with one minor change; it uses tabs. Blatantly violating PEP8 W191.

Go see the [official](https://black.readthedocs.io/en/stable/) readme to learn about how 
to use black and all of the great features it has. Black-With-Tabs is just piggybacking off of all the great work of the Black developers.

**Note: Black-With-Tabs intentionally uses the same namespace and calling as Black, so you cannot have both installed at the ame time!**

## Installation

Black-With-Tabs can be installed by running `pip install black-with-tabs`. It requires Python 3.6.0+ to
run but you can reformat Python 2 code with it, too.

![Tabs](https://raw.githubusercontent.com/ferret-guy/black-with-tabs/master/docs/_static/readme-tabs.jpg)
